@@ -10,8 +10,8 @@ import pandas as pd
 import unyts
 
 
-__version__ = '0.1.3'
-__release__ = 20230219
+__version__ = '0.1.4'
+__release__ = 20230220
 __all__ = ['Log']
 
 
@@ -151,7 +151,10 @@ class Log(object, metaclass=Log2FrameType):
             index_units = index_units.index_units
         if hasattr(self.data, 'index_to'):
             data = self.data.index_to(index_units)
-            if data.index.units == self.data.index.units:
+            if data.index.units == index_units:
+                logging.info("index units are already '" + str(index_units) + "'.")
+                return self
+            elif data.index.units == self.data.index.units:
                 logging.warning("index units not converted!")
                 units = self.units
             else:
@@ -239,6 +242,14 @@ class Log(object, metaclass=Log2FrameType):
             else:
                 logging.warning(msg)
 
+    def sort(self, inplace=False):
+        if inplace:
+            self.data.sort_index(inplace=True)
+        else:
+            result = self.copy()
+            result.data.sort_index(inplace=True)
+            return result
+
     def to(self, units, curve=None):
         if curve is not None:
             if type(curve) is str and type(units) is str:
